import { Component } from '@angular/core';
import { NavController, NavParams } from 'ionic-angular';
import { GoogleLoginResponseModel } from '../../models/google-login-response.model';
import { GooglePlus } from '@ionic-native/google-plus';
import { TokenGenHandleService } from '@justbe-ionic-angular/auth-data-handler';
import { StoreService } from '@justbe-angular/jb-store';
var google_main_tpl = "\n<ion-content class=\"jb-google-auth-bg-clr\">\n    <div class=\"backbutton\" (click)=\"cancel()\">Cancel</div>\n    <div class=\"ripplePosition\">\n        <div class=\"lds-ripple\">\n            <div></div>\n            <div></div>\n        </div>\n    </div>\n    <div class=\"currentStatusContainer\">\n        {{currentMsg}}\n    </div>\n</ion-content>\n";
var google_main_css = "\n.currentStatusContainer{\n    position: absolute;\n    top: 51%;\n    font-size: 1.5em;\n    color: aliceblue;\n    padding: 4%;\n}\n.ripplePosition{\n    position: absolute;\n    top: 36%;\n    left: 42%;\n}\n.backbutton{\n    position: absolute;\n    right: 5%;\n    top: 3%;\n    color: aliceblue;\n}\n.lds-ripple {\n    display: inline-block;\n    position: relative;\n    width: 64px;\n    height: 64px;\n  }\n  .lds-ripple div {\n    position: absolute;\n    border: 4px solid #cef;\n    opacity: 1;\n    border-radius: 50%;\n    animation: lds-ripple 1s cubic-bezier(0, 0.2, 0.8, 1) infinite;\n  }\n  .lds-ripple div:nth-child(2) {\n    animation-delay: -0.5s;\n  }\n  @keyframes lds-ripple {\n    0% {\n      top: 28px;\n      left: 28px;\n      width: 0;\n      height: 0;\n      opacity: 1;\n    }\n    100% {\n      top: -1px;\n      left: -1px;\n      width: 58px;\n      height: 58px;\n      opacity: 0;\n    }\n  }\n  \n";
var GoogleAuthPage = (function () {
    function GoogleAuthPage(navCtrl, googlePlus, tokenGenNHandle, navParams, storeService) {
        this.navCtrl = navCtrl;
        this.googlePlus = googlePlus;
        this.tokenGenNHandle = tokenGenNHandle;
        this.navParams = navParams;
        this.storeService = storeService;
    }
    GoogleAuthPage.prototype.ngOnInit = function () {
        this.currentMsg = 'Authenticating user using google.';
        this.observer = this.navParams.data.observer;
        this.login();
    };
    GoogleAuthPage.prototype.login = function () {
        var _this = this;
        var currentContext = this;
        this.googlePlus.login({})
            .then(function (googleProfile) {
            if (googleProfile.givenName) {
                currentContext.currentMsg = 'Setting up your account.';
                var oneLouveProfile = GoogleLoginResponseModel.googleLoginResponseToOneLouveProfile(googleProfile);
                currentContext.tokenGenNHandle.genNHandle({ profileType: 'Google2Profile', oneLouveProfile: oneLouveProfile, userId: googleProfile.userId }).subscribe(function (res) {
                    if (res === 200) {
                        currentContext.currentMsg = 'Welcome, ' + googleProfile.givenName + ' ' + googleProfile.familyName + '.';
                        currentContext.navCtrl.pop().then(function (res) {
                            currentContext.observer.next({
                                "jb-mobile-auth-json": currentContext.storeService.store["jb-mobile-auth-json"],
                                "jb-auth": currentContext.storeService.store["jb-auth"]
                            });
                            currentContext.observer.complete();
                        });
                    }
                });
            }
        }).catch(function (err) {
            _this.currentMsg = _this.currentMsg + ' ' + err;
        });
    };
    GoogleAuthPage.prototype.cancel = function () {
        this.navCtrl.pop();
    };
    GoogleAuthPage.decorators = [
        { type: Component, args: [{
                    selector: 'main-page',
                    template: google_main_tpl,
                    styles: [google_main_css]
                },] },
    ];
    /** @nocollapse */
    GoogleAuthPage.ctorParameters = function () { return [
        { type: NavController, },
        { type: GooglePlus, },
        { type: TokenGenHandleService, },
        { type: NavParams, },
        { type: StoreService, },
    ]; };
    return GoogleAuthPage;
}());
export { GoogleAuthPage };
//# sourceMappingURL=google-auth.page.js.map